/* vim:fdm=marker ts=4 et ai
 * {{{
 *
 * (c) by Alexander Neumann <alexander@bumpern.de>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * For more information on the GPL, please go to:
 * http://www.gnu.org/copyleft/gpl.html
 }}} */

#include <avr/io.h>
#include <avr/interrupt.h>
#include <avr/wdt.h>
#include <util/delay.h>
#include <stdlib.h>
#include "uart.h"


#include "common.h"
#include "network.h"

#include <etherrape.h>
#include <uip/uip.h>

/* macros */
#ifdef USE_WATCHDOG
#   define wdt_kick() wdt_reset()
#else
#   define wdt_kick()
#endif

int main(void)
{

#   ifdef USE_WATCHDOG
    /* test for reset cause */
    if (MCUSR & _BV(WDRF)) {
        /* clear flags */
        MCUSR &= ~_BV(WDRF);
    }

    /* set watchdog to 2 seconds */
    wdt_enable(WDTO_2S);
    wdt_kick();
#   else
    wdt_disable();
#   endif

    librape_init();

    /* initialize hardware uart */
    uart_init();

    echo_init();
    cube_init();
    
    while(1) {
        /* check for serial data */
        if (_UCSRA_UART0 & _BV(_RXC_UART0)) {
            check_serial_input(_UDR_UART0);
        }

        wdt_kick();
        librape_periodic();
    } 
}
